@@ -5,14 +5,14 @@ import argparse
 
 from deepchain.cli.set_backend import SetBackendCommand
 
-from .apps import AppsCommand
-from .auth import AuthCommand
-from .deploy import DeployCommand
-from .download import DownloadCommand
-from .config import ConfigCommand
+from deepchain.cli.apps import AppsCommand
+from deepchain.cli.auth import AuthCommand
+from deepchain.cli.deploy import DeployCommand
+from deepchain.cli.download import DownloadCommand
+from deepchain.cli.config import ConfigCommand
 
 # from .inference import InferenceCommand
-from .scaffold import CreateCommand
+from deepchain.cli.scaffold import CreateCommand
 
 
 def main():
