@@ -3,7 +3,6 @@ from argparse import ArgumentParser
 
 from deepchain import log
 from deepchain.cli import BaseCLICommand
-from deepchain.cli.cli_utils import get_config_url
 from deepchain.utils.validation import _check_app_files, _check_checkpoint_files
 
 from .apps_utils import (
@@ -49,9 +48,9 @@ class DeployCommand(BaseCLICommand):
         Check App to be deployed with validation function
         Upload checkpoint if needed
         """
-        url = get_config_url()
         configuration = get_configuration()
         pat = configuration["pat"]
+        url = configuration["backend_url"]
 
         app_name = self.app_name
         app_dir = get_app_info(app_name, kind="dir")
