@@ -5,11 +5,12 @@ import os
 import sys
 from json.decoder import JSONDecodeError
 from pathlib import Path
-from typing import List
 
-from deepchain import AppNotFoundError, CheckpointNotFoundError, log
+from deepchain import log
 from deepchain.cli.apps_utils import get_app_info
-from deepchain.utils.constants import EXTENSIONS, TAGS_KEY
+
+# from deepchain.utils.constants import TAGS_KEY
+from deepchain.utils.exceptions import AppNotFoundError, CheckpointNotFoundError
 
 
 def _check_checkpoint_files(app_name: str):
@@ -22,19 +23,19 @@ def _check_checkpoint_files(app_name: str):
     if not checkpoint_dir.is_dir():
         raise FileNotFoundError(f"You must have a checkpoint folder in the {app_dir} folder")
 
-    model_found = _check_file_extension(checkpoint_dir, EXTENSIONS)
+    model_found = _check_file_extension(checkpoint_dir)
     if not model_found:
-        raise CheckpointNotFoundError(EXTENSIONS)
+        raise CheckpointNotFoundError
 
 
-def _check_file_extension(folder_path: Path, extension_list: List) -> bool:
+def _check_file_extension(folder_path: Path) -> bool:
     """Check if file of extension list are found in folder"""
     model_found = False
     for file in folder_path.glob("*"):
         base_file = os.path.basename(file)
         _, ext_ = os.path.splitext(base_file)
 
-        if ext_ in extension_list:
+        if ext_ != ".py":
             model_found = True
             break
     return model_found
@@ -76,7 +77,7 @@ def _check_init(app_dir: Path) -> None:
     """Check if init file is in folder"""
     path_init = app_dir.joinpath("__init__.py")
     if not path_init.is_file():
-        raise FileNotFoundError("The app folder must be a module and contain __init__.py file")
+        raise FileNotFoundError("The app folder must be a module and contains __init__.py file")
 
 
 def _check_app(app_dir: Path) -> None:
@@ -106,15 +107,15 @@ def _check_json(app_dir: Path) -> bool:
         msg = "Invalid tags.json file, check if you use double quote \" and not single quote ' "
         raise TypeError(msg) from err
 
-    key = list(tags.keys())
-    key = sorted(key)
+    # key = list(tags.keys())
+    # key = sorted(key)
 
-    if not (key == sorted(TAGS_KEY)):
-        message = f"tags.json file only accept the following keys : {'-'.join(TAGS_KEY)}"
-        raise KeyError(message)
+    # if not (key == sorted(TAGS_KEY)):
+    #    message = f"tags.json file only accept the following keys : {'-'.join(TAGS_KEY)}"
+    #    raise KeyError(message)
 
     for k, v in tags.items():
-        if not isinstance(v, list) and k != "device":
+        if not isinstance(v, list):
             raise TypeError(
                 "The value of the json file should be of type list, even empty, except for device."
             )
